@@ -292,6 +292,7 @@ NautilusView *      fm_directory_view_get_nautilus_view                (FMDirect
 
 /* Functions callable from the user interface and elsewhere. */
 char *              fm_directory_view_get_uri                          (FMDirectoryView  *view);
+char *              fm_directory_view_get_backing_uri                  (FMDirectoryView  *view);
 gboolean            fm_directory_view_can_accept_item                  (NautilusFile     *target_item,
 									const char       *item_uri,
 									FMDirectoryView  *view);
@@ -342,7 +343,9 @@ void                fm_directory_view_end_loading                      (FMDirect
  * FMDirectoryView and its subclasses 
  */
 void                fm_directory_view_activate_files                   (FMDirectoryView  *view,
-									GList            *files);
+									GList            *files,
+									Nautilus_ViewFrame_OpenMode mode,
+									Nautilus_ViewFrame_OpenFlags flags);
 void                fm_directory_view_start_batching_selection_changes (FMDirectoryView  *view);
 void                fm_directory_view_stop_batching_selection_changes  (FMDirectoryView  *view);
 gboolean            fm_directory_view_confirm_multiple_windows         (FMDirectoryView  *view,
